@@ -16,7 +16,9 @@ from tornado.gen import Task
 from .libs import Copyright
 from .libs import yaml2py, utils
 from .libs.route import route
-from .libs.docs.generate_docs import GenerateDocs
+try:
+    from .libs.docs.generate_docs import GenerateDocs
+except:pass
 from .libs.services import ServicesFindet
 from .base import BaseHandler, BaseModel
 from .test.docshandler import DocsHandler
@@ -109,7 +111,7 @@ class App(tornado.web.Application):
         self.api_schema_mp = yaml2py.load_api_schema(self.api_schema_dir)
 
     def create_base(self):
-        s = os.path.join(self.ROOT, "base.py")
+        s = utils.fix_path(os.path.join(self.ROOT, "base.py"))
         if not os.path.exists(s) and self.kwargs.get("auto_generate_base", True):
             yaml2py.generate_basepy(self.ROOT + "/base.py", self.jinja2_path_dir)
 
@@ -121,7 +123,7 @@ class App(tornado.web.Application):
         if not self.kwargs.get("auto_generate_py", True):
             return
 
-        handler_init = os.path.join(self.handler_dir, "__init__.py")
+        handler_init = utils.fix_path(os.path.join(self.handler_dir, "__init__.py"))
         if not os.path.exists(self.handler_dir) or not os.path.exists(handler_init):
             if not os.path.exists(self.handler_dir):
                 os.mkdir(self.handler_dir)
@@ -137,7 +139,7 @@ class App(tornado.web.Application):
             return
 
         self.model_schema_dir = self.model_dir + "/schema"
-        model_init = os.path.join(self.model_dir, "__init__.py")
+        model_init = utils.fix_path(os.path.join(self.model_dir, "__init__.py"))
 
         if not os.path.exists(self.model_dir) or not os.path.exists(model_init):
             if not os.path.exists(self.model_dir):
@@ -147,7 +149,7 @@ class App(tornado.web.Application):
                 with open(os.path.join(model_init), "w", encoding='utf-8') as p:
                     p.write(Copyright.file_pre)
 
-            schema_init = os.path.join(self.model_schema_dir, "__init__.py")
+            schema_init = utils.fix_path(os.path.join(self.model_schema_dir, "__init__.py"))
             if not os.path.exists(self.model_schema_dir):
                 os.mkdir(self.model_schema_dir)
 
@@ -157,7 +159,7 @@ class App(tornado.web.Application):
 
         yaml2py.generate_resource_model(self.model_dir, self.api_schema_mp, self.jinja2_path_dir)
 
-        schema_init = os.path.join(self.model_schema_dir, "__init__.py")
+        schema_init = utils.fix_path(os.path.join(self.model_schema_dir, "__init__.py"))
         if not os.path.exists(schema_init):
             with open(schema_init, "w", encoding='utf-8') as p:
                 p.write(Copyright.file_pre)
@@ -239,7 +241,10 @@ class App(tornado.web.Application):
         http_server.start()
         ioloop = IOLoop.instance()
         self.periodic_callback()
-        GenerateDocs.start(self)
+        try:
+            GenerateDocs.start(self)
+        except Exception as e:
+            logging.error(str(e))
         def signal_handler(sig, frame):
             ioloop.add_callback(shutdown)
         def shutdown():
